# This is Python API for myCobot

If you want to install it separately.

## Installation

### Pip

```bash
pip install pymycobot --upgrade
```

### Source code

```bash
git clone https://github.com/elephantrobotics/pymycobot.git <your-path>
cd <your-path>/pymycobot
# Install
python2 setup.py install
# or
python3 setup.py install
```

**_`test/test.py` is a test file, you can find out which interfaces pymycobot provides in `pymycobot/README.md`._**

## Usage:

Please go to [here](./pymycobot/README.md).

**Notes**:

<!-- This is the mycobot Python API package designed by Zhang Lijun([lijun.zhang@elephantrobotics.com]()) -->

> Make sure that `Atom2.3` is flashed into the top Atom <br> > `Transponder` is flashed into the base Basic <br>
> The firmware `Atom2.3` and `Transponder` download address: [https://github.com/elephantrobotics/myCobot/tree/main/Software](https://github.com/elephantrobotics/myCobot/tree/main/Software)<br>
> Python 2: use mycobot.py <br>
> Python 3: use mycobot3.py
